@@ -1,6 +1,7 @@
 ﻿define(['layoutManager', 'cardBuilder', 'datetime', 'mediaInfo', 'backdrop', 'listView', 'itemContextMenu', 'itemHelper', 'userdataButtons', 'dom', 'indicators', 'apphost', 'scrollStyles', 'emby-itemscontainer', 'emby-checkbox'], function (layoutManager, cardBuilder, datetime, mediaInfo, backdrop, listView, itemContextMenu, itemHelper, userdataButtons, dom, indicators, appHost) {
 
     var currentItem;
+    var currentRecordingFields;
 
     function getPromise(params) {
 
@@ -172,25 +173,7 @@
                 hideAll(page, 'syncLocalContainer');
             }
 
-            if (item.Type == 'Program' && item.TimerId) {
-                hideAll(page, 'btnCancelRecording', true);
-            } else {
-                hideAll(page, 'btnCancelRecording');
-            }
-
-            if (item.Type == 'Program' && (!item.TimerId && !item.SeriesTimerId)) {
-
-                if (canPlay) {
-                    hideAll(page, 'btnRecord', true);
-                    hideAll(page, 'btnFloatingRecord');
-                } else {
-                    hideAll(page, 'btnRecord');
-                    hideAll(page, 'btnFloatingRecord', true);
-                }
-            } else {
-                hideAll(page, 'btnRecord');
-                hideAll(page, 'btnFloatingRecord');
-            }
+            showRecordingFields(page, item, user);
 
             var btnPlayExternalTrailer = page.querySelectorAll('.btnPlayExternalTrailer');
             for (var i = 0, length = btnPlayExternalTrailer.length; i < length; i++) {
@@ -224,12 +207,6 @@
                 }
             });
 
-            if (user.Policy.IsAdministrator) {
-                page.querySelector('.chapterSettingsButton').classList.remove('hide');
-            } else {
-                page.querySelector('.chapterSettingsButton').classList.add('hide');
-            }
-
             var itemBirthday = page.querySelector('#itemBirthday');
             if (item.Type == "Person" && item.PremiereDate) {
 
@@ -314,6 +291,31 @@
         Dashboard.hideLoadingMsg();
     }
 
+    function showRecordingFields(page, item, user) {
+
+        if (currentRecordingFields) {
+            return;
+        }
+
+        var recordingFieldsElement = page.querySelector('.recordingFields');
+
+        if (item.Type == 'Program' && user.Policy.EnableLiveTvManagement) {
+
+            require(['recordingFields'], function (recordingFields) {
+
+                currentRecordingFields = new recordingFields({
+                    parent: recordingFieldsElement,
+                    programId: item.Id,
+                    serverId: item.ServerId
+                });
+                recordingFieldsElement.classList.remove('hide');
+            });
+        } else {
+            recordingFieldsElement.classList.add('hide');
+            recordingFieldsElement.innerHTML = '';
+        }
+    }
+
     function renderLinks(linksElem, item) {
 
         var links = [];
@@ -444,6 +446,11 @@
             page.querySelector('#childrenCollapsible').classList.add('hide');
         }
 
+        if (item.Type == 'Series') {
+
+            renderSeriesSchedule(page, item, user);
+        }
+
         if (item.Type == 'Series') {
 
             renderNextUp(page, item, user);
@@ -565,7 +572,8 @@
         var itemMiscInfo = page.querySelectorAll('.itemMiscInfo');
         for (i = 0, length = itemMiscInfo.length; i < length; i++) {
             mediaInfo.fillPrimaryMediaInfo(itemMiscInfo[i], item, {
-                interactive: true
+                interactive: true,
+                episodeTitle: false
             });
         }
         var itemGenres = page.querySelectorAll('.itemGenres');
@@ -859,14 +867,18 @@
 
             var shape = item.Type == "MusicAlbum" || item.Type == "MusicArtist" ? getSquareShape() : getPortraitShape();
 
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+
             html += cardBuilder.getCardsHtml({
                 items: result.Items,
                 shape: shape,
                 showParentTitle: item.Type == "MusicAlbum",
-                centerText: true,
+                centerText: !supportsImageAnalysis,
                 showTitle: item.Type == "MusicAlbum" || item.Type == "Game" || item.Type == "MusicArtist",
                 coverImage: item.Type == "MusicAlbum" || item.Type == "MusicArtist",
-                overlayPlayButton: true
+                overlayPlayButton: true,
+                cardLayout: supportsImageAnalysis,
+                vibrant: supportsImageAnalysis
             });
             html += '</div>';
 
@@ -896,7 +908,7 @@
 
         var options = {
             userId: Dashboard.getCurrentUserId(),
-            limit: 8,
+            limit: item.Type == "MusicAlbum" || item.Type == "MusicArtist" ? 8 : 10,
             fields: "PrimaryImageAspectRatio,UserData,CanDelete"
         };
 
@@ -917,7 +929,6 @@
             }
 
             similarCollapsible.classList.remove('hide');
-            similarCollapsible.querySelector('.similiarHeader').innerHTML = Globalize.translate('HeaderIfYouLikeCheckTheseOut', item.Name);
 
             var html = '';
 
@@ -926,21 +937,27 @@
             } else {
                 html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
             }
+
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+            var cardLayout = supportsImageAnalysis && (item.Type == "MusicAlbum" || item.Type == "Game" || item.Type == "MusicArtist");
+
             html += cardBuilder.getCardsHtml({
                 items: result.Items,
                 shape: shape,
                 showParentTitle: item.Type == "MusicAlbum",
-                centerText: true,
+                centerText: !cardLayout,
                 showTitle: item.Type == "MusicAlbum" || item.Type == "Game" || item.Type == "MusicArtist",
                 context: context,
                 lazy: true,
                 showDetailsMenu: true,
                 coverImage: item.Type == "MusicAlbum" || item.Type == "MusicArtist",
-                overlayPlayButton: true
+                overlayPlayButton: true,
+                cardLayout: cardLayout,
+                vibrant: cardLayout && supportsImageAnalysis
             });
             html += '</div>';
 
-            var similarContent = page.querySelector('#similarContent');
+            var similarContent = similarCollapsible.querySelector('.similarContent');
             similarContent.innerHTML = html;
             ImageLoader.lazyChildren(similarContent);
         });
@@ -1110,7 +1127,8 @@
                     showIndexNumber: true,
                     playFromHere: true,
                     action: 'playallfromhere',
-                    lazy: true
+                    image: false,
+                    artist: false
                 });
                 isList = true;
             }
@@ -1139,7 +1157,7 @@
                     overlayText: true,
                     lazy: true,
                     showDetailsMenu: true,
-                    overlayPlayButton: AppInfo.enableAppLayouts
+                    overlayPlayButton: true
                 });
             }
             else if (item.Type == "GameSystem") {
@@ -1230,10 +1248,49 @@
 
     function renderChannelGuide(page, item, user) {
 
-        require('scripts/livetvcomponents,scripts/livetvchannel,livetvcss'.split(','), function () {
+        require('scripts/livetvchannel,scripts/livetvcomponents,livetvcss'.split(','), function (liveTvChannelPage) {
 
+            liveTvChannelPage.renderPrograms(page, item.Id);
+        });
+    }
 
-            LiveTvChannelPage.renderPrograms(page, item.Id);
+    function renderSeriesSchedule(page, item, user) {
+
+        return;
+        ApiClient.getLiveTvPrograms({
+
+            UserId: Dashboard.getCurrentUserId(),
+            HasAired: false,
+            SortBy: "StartDate",
+            EnableTotalRecordCount: false,
+            EnableImages: false,
+            ImageTypeLimit: 0,
+            Limit: 50,
+            EnableUserData: false,
+            LibrarySeriesId: item.Id
+
+        }).then(function (result) {
+
+            if (result.Items.length) {
+                page.querySelector('#seriesScheduleSection').classList.remove('hide');
+
+            } else {
+                page.querySelector('#seriesScheduleSection').classList.add('hide');
+            }
+
+            page.querySelector('#seriesScheduleList').innerHTML = listView.getListViewHtml({
+                items: result.Items,
+                enableUserDataButtons: false,
+                showParentTitle: false,
+                image: false,
+                showProgramDateTime: true,
+                mediaInfo: false,
+                showTitle: true,
+                moreButton: false,
+                action: 'programdialog'
+            });
+
+            Dashboard.hideLoadingMsg();
         });
     }
 
@@ -1403,13 +1460,13 @@
 
         var userDataIcons = page.querySelectorAll('.userDataIcons');
 
-        var html = userdataButtons.getIconsHtml({
-            item: item,
-            style: 'fab-mini'
-        });
-
         for (var i = 0, length = userDataIcons.length; i < length; i++) {
-            userDataIcons[i].innerHTML = html;
+
+            userdataButtons.fill({
+                item: item,
+                style: 'fab-mini',
+                element: userDataIcons[i]
+            });
         }
     }
 
@@ -1636,10 +1693,13 @@
             });
         });
 
-        if (limitExceeded) {
-            page.querySelector('.moreScenes').classList.remove('hide');
-        } else {
-            page.querySelector('.moreScenes').classList.add('hide');
+        var moreScenesButton = page.querySelector('.moreScenes');
+        if (moreScenesButton) {
+            if (limitExceeded) {
+                moreScenesButton.classList.remove('hide');
+            } else {
+                moreScenesButton.classList.add('hide');
+            }
         }
     }
 
@@ -1807,73 +1867,14 @@
 
     function getVideosHtml(items, user, limit, moreButtonClass) {
 
-        var html = '';
-
-        for (var i = 0, length = items.length; i < length; i++) {
-
-            if (limit && i >= limit) {
-                break;
-            }
-
-            var item = items[i];
-
-            var cssClass = "card backdropCard scalableCard backdropCard-scalable";
-
-            var href = "itemdetails.html?id=" + item.Id;
-
-            var onclick = item.PlayAccess == 'Full' ? ' onclick="MediaController.play(\'' + item.Id + '\'); return false;"' : "";
-
-            html += '<a class="' + cssClass + '" href="' + href + '"' + onclick + '>';
-
-            html += '<div class="cardBox">';
-            html += '<div class="cardScalable">';
-
-            var imageTags = item.ImageTags || {};
-
-            var imgUrl;
-
-            if (imageTags.Primary) {
-
-                imgUrl = ApiClient.getScaledImageUrl(item.Id, {
-                    maxWidth: 400,
-                    tag: imageTags.Primary,
-                    type: "primary"
-                });
-
-            } else {
-                imgUrl = "css/images/items/detail/video.png";
-            }
-
-            html += '<div class="cardPadder cardPadder-backdrop"></div>';
-
-            html += '<div class="cardContent">';
-            html += '<div class="cardImage lazy" data-src="' + imgUrl + '"></div>';
-
-            html += '<div class="innerCardFooter">';
-            html += '<div class="cardText">' + item.Name + '</div>';
-            html += '<div class="cardText">';
-            if (item.RunTimeTicks != "") {
-                html += datetime.getDisplayRunningTime(item.RunTimeTicks);
-            }
-            else {
-                html += "&nbsp;";
-            }
-            html += '</div>';
-
-            //cardFooter
-            html += "</div>";
-
-            // cardContent
-            html += '</div>';
-
-            // cardScalable
-            html += '</div>';
-
-            // cardBox
-            html += '</div>';
-
-            html += '</a>';
-        }
+        var html = cardBuilder.getCardsHtml({
+            items: items,
+            shape: "auto",
+            showTitle: true,
+            action: 'play',
+            overlayText: true,
+            showRuntime: true
+        });
 
         if (limit && items.length > limit) {
             html += '<p style="margin: 0;padding-left:5px;"><button is="emby-button" type="button" class="raised more ' + moreButtonClass + '">' + Globalize.translate('ButtonMore') + '</button></p>';
@@ -1923,10 +1924,13 @@
             });
         });
 
-        if (limitExceeded && !enableScrollX()) {
-            page.querySelector('.morePeople').classList.remove('hide');
-        } else {
-            page.querySelector('.morePeople').classList.add('hide');
+        var morePeopleButton = page.querySelector('.morePeople');
+        if (morePeopleButton) {
+            if (limitExceeded && !enableScrollX()) {
+                morePeopleButton.classList.remove('hide');
+            } else {
+                morePeopleButton.classList.add('hide');
+            }
         }
     }
 
@@ -2133,16 +2137,6 @@
             elems[i].addEventListener('change', onSyncLocalClick);
         }
 
-        elems = view.querySelectorAll('.btnRecord,.btnFloatingRecord');
-        for (i = 0, length = elems.length; i < length; i++) {
-            elems[i].addEventListener('click', onRecordClick);
-        }
-
-        elems = view.querySelectorAll('.btnCancelRecording');
-        for (i = 0, length = elems.length; i < length; i++) {
-            elems[i].addEventListener('click', onCancelRecordingClick);
-        }
-
         elems = view.querySelectorAll('.btnMoreCommands');
         for (i = 0, length = elems.length; i < length; i++) {
             elems[i].addEventListener('click', onMoreCommandsClick);
@@ -2226,10 +2220,6 @@
 
         }
 
-        view.querySelector('.chapterSettingsButton').addEventListener('click', function () {
-            Dashboard.navigate('librarysettings.html');
-        });
-
         view.addEventListener('viewbeforeshow', function () {
             var page = this;
             reload(page, params);
@@ -2240,6 +2230,7 @@
         view.addEventListener('viewbeforehide', function () {
 
             currentItem = null;
+            currentRecordingFields = null;
 
             Events.off(ApiClient, 'websocketmessage', onWebSocketMessage);
             LibraryMenu.setTransparentMenu(false);
