@@ -1,4 +1,4 @@
-﻿define(['imageLoader', 'layoutManager', 'viewManager', 'libraryBrowser', 'apphost', 'paper-icon-button-light', 'material-icons'], function (imageLoader, layoutManager, viewManager, libraryBrowser, appHost) {
+﻿define(['imageLoader', 'layoutManager', 'viewManager', 'libraryBrowser', 'apphost', 'embyRouter', 'paper-icon-button-light', 'material-icons'], function (imageLoader, layoutManager, viewManager, libraryBrowser, appHost, embyRouter) {
 
     var enableBottomTabs = AppInfo.isNativeApp;
     var enableLibraryNavDrawer = !enableBottomTabs;
@@ -60,7 +60,7 @@
 
     function onBackClick() {
 
-        Emby.Page.back();
+        embyRouter.back();
     }
 
     function updateUserInHeader(user) {
@@ -908,7 +908,7 @@
         var backButton = document.querySelector('.headerBackButton');
 
         if (backButton) {
-            if (page.getAttribute('data-backbutton') == 'true' && Emby.Page.canGoBack()) {
+            if (page.getAttribute('data-backbutton') == 'true' && embyRouter.canGoBack()) {
                 backButton.classList.remove('hide');
             } else {
                 backButton.classList.add('hide');
