@@ -75,7 +75,8 @@
         require(['prompt'], function (prompt) {
 
             prompt({
-                label: Globalize.translate('LabelNewName')
+                label: Globalize.translate('LabelNewName'),
+                confirmText: Globalize.translate('ButtonRename')
 
             }).then(function (newName) {
                 if (newName && newName != virtualFolder.Name) {
@@ -227,10 +228,13 @@
 
     function editImages(page, virtualFolder) {
 
-        require(['components/imageeditor/imageeditor'], function (ImageEditor) {
+        require(['imageEditor'], function (imageEditor) {
+
+            imageEditor.show({
+                
+                itemId: virtualFolder.ItemId,
+                serverId: ApiClient.serverId()
 
-            ImageEditor.show(virtualFolder.ItemId, {
-                theme: 'a'
             }).then(function () {
                 reloadLibrary(page);
             });
@@ -297,10 +301,10 @@
             style += "min-width:33.3%;";
         }
 
-        html += '<div class="card backdropCard scalableCard" style="' + style + '" data-index="' + index + '">';
+        html += '<div class="card backdropCard scalableCard backdropCard-scalable" style="' + style + '" data-index="' + index + '">';
 
         html += '<div class="cardBox visualCardBox">';
-        html += '<div class="cardScalable">';
+        html += '<div class="cardScalable visualCardBox-cardScalable">';
 
         html += '<div class="cardPadder cardPadder-backdrop"></div>';
 
@@ -325,7 +329,7 @@
         if (!imgUrl && virtualFolder.showNameWithIcon) {
             html += '<h1 class="cardImageContainer addLibrary" style="position:absolute;top:0;left:0;right:0;bottom:0;cursor:pointer;flex-direction:column;">';
 
-            html += '<i class="cardImageIcon md-icon" style="font-size:300%;color:#888;height:auto;width:auto;">' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '</i>';
+            html += '<i class="cardImageIcon md-icon" style="font-size:240%;color:#888;height:auto;width:auto;">' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '</i>';
 
             if (virtualFolder.showNameWithIcon) {
                 html += '<div style="margin:1em 0;position:width:100%;font-weight:500;color:#444;">';
@@ -342,7 +346,7 @@
         // cardScalable
         html += "</div>";
 
-        html += '<div class="cardFooter">';
+        html += '<div class="cardFooter visualCardBox-cardFooter">';
 
         if (virtualFolder.showMenu !== false) {
             var moreIcon = appHost.moreIcon == 'dots-horiz' ? '&#xE5D3;' : '&#xE5D4;';
@@ -432,7 +436,7 @@
         return [
         {
             href: 'library.html',
-            name: Globalize.translate('TabFolders')
+            name: Globalize.translate('HeaderLibraries')
         },
          {
              href: 'librarydisplay.html',
