@@ -1,4 +1,4 @@
-﻿define(['appSettings', 'datetime', 'mediaInfo', 'scrollStyles', 'paper-icon-button-light'], function (appSettings, datetime, mediaInfo) {
+﻿define(['appSettings', 'datetime', 'mediaInfo', 'browser', 'scrollStyles', 'paper-icon-button-light'], function (appSettings, datetime, mediaInfo, browser) {
 
     function createVideoPlayer(self) {
 
@@ -413,7 +413,24 @@
 
             var elem = mediaControls.querySelector('.nowPlayingTabs');
             elem.innerHTML = getNowPlayingTabsHtml(item.CurrentProgram || item);
-            ImageLoader.lazyChildren(elem);
+
+            var tabCast = elem.querySelector('.tabCast');
+            if (tabCast) {
+                require(['peoplecardbuilder'], function (peoplecardbuilder) {
+
+                    peoplecardbuilder.buildPeopleCards((item.CurrentProgram || item).People || [], {
+                        itemsContainer: tabCast,
+                        coverImage: true,
+                        serverId: ApiClient.serverId(),
+                        width: 160,
+                        shape: 'portrait'
+                    });
+                    ImageLoader.lazyChildren(elem);
+                });
+            }
+            else {
+                ImageLoader.lazyChildren(elem);
+            }
 
             function onTabButtonClick() {
                 if (!this.classList.contains('selectedNowPlayingTabButton')) {
@@ -540,79 +557,17 @@
 
             if (item.People && item.People.length) {
                 html += '<div class="tabCast nowPlayingTab smoothScrollX hide" style="white-space:nowrap;">';
-                html += item.People.map(function (cast) {
-
-                    var personHtml = '<div class="tileItem smallPosterTileItem" style="width:300px;">';
-
-                    var imgUrl;
-                    var height = 150;
-
-                    if (cast.PrimaryImageTag) {
-
-                        imgUrl = ApiClient.getScaledImageUrl(cast.Id, {
-                            height: height,
-                            tag: cast.PrimaryImageTag,
-                            type: "primary",
-                            minScale: 2
-                        });
-
-                        personHtml += '<div class="tileImage lazy" data-src="' + imgUrl + '" style="height:' + height + 'px;"></div>';
-                    } else {
-
-                        imgUrl = "css/images/items/list/person.png";
-                        personHtml += '<div class="tileImage" style="background-image:url(\'' + imgUrl + '\');height:' + height + 'px;"></div>';
-                    }
-
-                    personHtml += '<div class="tileContent">';
-
-                    personHtml += '<p>' + cast.Name + '</p>';
-
-                    var role = cast.Role ? Globalize.translate('ValueAsRole', cast.Role) : cast.Type;
-
-                    if (role == "GuestStar") {
-                        role = Globalize.translate('ValueGuestStar');
-                    }
-
-                    role = role || "";
-
-                    var maxlength = 40;
-
-                    if (role.length > maxlength) {
-                        role = role.substring(0, maxlength - 3) + '...';
-                    }
-
-                    personHtml += '<p>' + role + '</p>';
-
-                    personHtml += '</div>';
-
-                    personHtml += '</div>';
-                    return personHtml;
-
-                }).join('');
                 html += '</div>';
             }
 
             return html;
         }
 
-        function getSeekableDuration() {
-
-            if (self.currentMediaSource && self.currentMediaSource.RunTimeTicks) {
-                return self.currentMediaSource.RunTimeTicks;
-            }
-
-            if (self.currentMediaRenderer) {
-                return self.getCurrentTicks(self.currentMediaRenderer);
-            }
-
-            return null;
-        }
-
         function onPositionSliderChange() {
 
             var newPercent = parseFloat(this.value);
 
-            var newPositionTicks = (newPercent / 100) * getSeekableDuration();
+            var newPositionTicks = (newPercent / 100) * self.getSeekableDurationTicks();
 
             self.changeStream(Math.floor(newPositionTicks));
         }
@@ -723,7 +678,7 @@
             html += '<div id="pause" class="status"></div>';
             html += '</div>';
 
-            var hiddenOnIdleClass = AppInfo.isNativeApp && browserInfo.android ? 'hiddenOnIdle hide' : 'hiddenOnIdle';
+            var hiddenOnIdleClass = AppInfo.isNativeApp && browser.android ? 'hiddenOnIdle hide' : 'hiddenOnIdle';
 
             html += '<div class="videoTopControls ' + hiddenOnIdleClass + '">';
             html += '<div class="videoTopControlsLogo"></div>';
@@ -808,7 +763,7 @@
 
             positionSlider.getBubbleText = function (value) {
 
-                var seekableDuration = getSeekableDuration();
+                var seekableDuration = self.getSeekableDurationTicks();
                 if (!self.currentMediaSource || !seekableDuration) {
                     return '--:--';
                 }
@@ -997,10 +952,11 @@
 
         self.playVideo = function (item, mediaSource, startPosition, callback) {
 
-            if (browserInfo.msie) {
+            if (browser.msie) {
 
-                if (!window.MediaSource || !mediaSource.RunTimeTicks) {
+                if (window.MediaSource == null || mediaSource.RunTimeTicks == null || browser.mobile) {
                     alert('Playback of this content is not supported in Internet Explorer. For a better experience, please try a modern browser such as Google Chrome, Firefox, Opera, or Microsoft Edge.');
+                    return;
                 }
             }
 
@@ -1011,15 +967,20 @@
 
                 self.createStreamInfo('Video', item, mediaSource, startPosition).then(function (streamInfo) {
 
+                    var onReadyToPlay = function () {
+                        self.playVideoInternal(item, mediaSource, startPosition, streamInfo, callback);
+                    };
+
                     var isHls = streamInfo.url.toLowerCase().indexOf('.m3u8') != -1;
 
                     // Huge hack alert. Safari doesn't seem to like if the segments aren't available right away when playback starts
                     // This will start the transcoding process before actually feeding the video url into the player
                     // Edit: Also seeing stalls from hls.js
-                    if (!mediaSource.RunTimeTicks && isHls) {
+                    if (!mediaSource.RunTimeTicks && isHls && (!browser.edge || !browser.mobile)) {
+
+                        var hlsPlaylistUrl = streamInfo.url.replace('master.m3u8', 'live.m3u8');
 
                         Dashboard.showLoadingMsg();
-                        var hlsPlaylistUrl = streamInfo.url.replace('master.m3u8', 'live.m3u8');
                         ApiClient.ajax({
 
                             type: 'GET',
@@ -1029,17 +990,14 @@
                             Dashboard.hideLoadingMsg();
                             streamInfo.url = hlsPlaylistUrl;
 
-                            // add a delay to continue building up the buffer. without this we see failures in safari mobile
-                            setTimeout(function () {
-                                self.playVideoInternal(item, mediaSource, startPosition, streamInfo, callback);
-                            }, 2000);
+                            setTimeout(onReadyToPlay, 0);
 
                         }, function () {
                             Dashboard.hideLoadingMsg();
                         });
 
                     } else {
-                        self.playVideoInternal(item, mediaSource, startPosition, streamInfo, callback);
+                        onReadyToPlay();
                     }
                 });
             });
@@ -1077,7 +1035,7 @@
 
             elem.classList.remove('hide');
 
-            if (!browserInfo.animate || browserInfo.slow) {
+            if (!browser.animate || browser.slow) {
                 return;
             }
 
@@ -1170,7 +1128,6 @@
             document.body.classList.add('bodyWithPopupOpen');
 
             self.currentMediaRenderer = mediaRenderer;
-            self.currentDurationTicks = self.currentMediaSource.RunTimeTicks;
 
             self.updateNowPlayingInfo(item);
 
@@ -1256,7 +1213,7 @@
                 errorMsg += '<br/>';
                 errorMsg += Globalize.translate('MessageEnsureOpenTuner');
             }
-            else if (mediaSource && mediaSource.VideoType != "VideoFile") {
+            else if (mediaSource && mediaSource.VideoType && mediaSource.VideoType != "VideoFile") {
                 errorMsg += '<br/>';
                 errorMsg += '<br/>';
                 errorMsg += Globalize.translate('MessageFolderRipPlaybackExperimental');
@@ -1276,7 +1233,7 @@
 
         function onClick() {
 
-            if (!browserInfo.mobile) {
+            if (!browser.mobile) {
                 if (this.paused()) {
                     self.unpause();
                 } else {
@@ -1286,7 +1243,7 @@
         }
 
         function onDoubleClick() {
-            if (!browserInfo.mobile) {
+            if (!browser.mobile) {
                 self.toggleFullscreen();
             }
         }
